==> pollen-ui-struts2-1.3.1.1-sources.jar: org/chorem/pollen/ui/actions/poll/DeletePoll.java <==
/*
 * #%L
 * Pollen :: UI (strust2)
 * 
 * $Id: DeletePoll.java 3257 2012-04-13 11:28:02Z fdesbois $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.3.1.1/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/poll/DeletePoll.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.poll;

import org.chorem.pollen.services.impl.PollService;

/**
 * Deletes an existing poll.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class DeletePoll extends AbstractPollUriIdAction {

    private static final long serialVersionUID = 1L;

    protected String redirectUrl;

    public String getRedirectUrl() {
        return redirectUrl;
    }

    public void setRedirectUrl(String redirectUrl) {
        this.redirectUrl = redirectUrl;
    }

    @Override
    public String execute() throws Exception {

        PollService service = newService(PollService.class);

        service.deletePoll(getPollId(), getPollenUserAccount(), getAccountId());
        return SUCCESS;
    }


}

==> pollen-ui-struts2-1.4-sources.jar: org/chorem/pollen/ui/actions/poll/DeletePoll.java <==
/*
 * #%L
 * Pollen :: UI (struts2)
 * $Id: DeletePoll.java 3423 2012-06-05 16:50:22Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.4/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/poll/DeletePoll.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.poll;

/**
 * Deletes an existing poll.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class DeletePoll extends AbstractPollUriIdAction {

    private static final long serialVersionUID = 1L;

    protected String redirectUrl;

    public String getRedirectUrl() {
        return redirectUrl;
    }

    public void setRedirectUrl(String redirectUrl) {
        this.redirectUrl = redirectUrl;
    }

    @Override
    public String execute() throws Exception {


        getPollService().deletePoll(getPollId(),
                                    getPollenUserAccount(),
                                    getAccountId());
        return SUCCESS;
    }


}
